==> openimageio-2.5.18.0-1.gpkg.tar: image/usr/lib64/cmake/OpenImageIO/OpenImageIOTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "OpenImageIO::OpenImageIO_Util" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::OpenImageIO_Util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::OpenImageIO_Util PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Boost::thread"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libOpenImageIO_Util.so.2.5.18"
  IMPORTED_SONAME_RELWITHDEBINFO "libOpenImageIO_Util.so.2.5"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::OpenImageIO_Util )
list(APPEND _cmake_import_check_files_for_OpenImageIO::OpenImageIO_Util "${_IMPORT_PREFIX}/lib64/libOpenImageIO_Util.so.2.5.18" )

# Import target "OpenImageIO::OpenImageIO" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::OpenImageIO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::OpenImageIO PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "OpenEXR::OpenEXR;libjpeg-turbo::jpeg;OpenEXR::OpenEXRCore;OpenColorIO::OpenColorIO;Boost::thread"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libOpenImageIO.so.2.5.18"
  IMPORTED_SONAME_RELWITHDEBINFO "libOpenImageIO.so.2.5"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::OpenImageIO )
list(APPEND _cmake_import_check_files_for_OpenImageIO::OpenImageIO "${_IMPORT_PREFIX}/lib64/libOpenImageIO.so.2.5.18" )

# Import target "OpenImageIO::iconvert" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::iconvert APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::iconvert PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/iconvert"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::iconvert )
list(APPEND _cmake_import_check_files_for_OpenImageIO::iconvert "${_IMPORT_PREFIX}/bin/iconvert" )

# Import target "OpenImageIO::idiff" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::idiff APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::idiff PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/idiff"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::idiff )
list(APPEND _cmake_import_check_files_for_OpenImageIO::idiff "${_IMPORT_PREFIX}/bin/idiff" )

# Import target "OpenImageIO::igrep" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::igrep APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::igrep PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/igrep"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::igrep )
list(APPEND _cmake_import_check_files_for_OpenImageIO::igrep "${_IMPORT_PREFIX}/bin/igrep" )

# Import target "OpenImageIO::iinfo" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::iinfo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::iinfo PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/iinfo"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::iinfo )
list(APPEND _cmake_import_check_files_for_OpenImageIO::iinfo "${_IMPORT_PREFIX}/bin/iinfo" )

# Import target "OpenImageIO::maketx" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::maketx APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::maketx PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/maketx"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::maketx )
list(APPEND _cmake_import_check_files_for_OpenImageIO::maketx "${_IMPORT_PREFIX}/bin/maketx" )

# Import target "OpenImageIO::oiiotool" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::oiiotool APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::oiiotool PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/oiiotool"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::oiiotool )
list(APPEND _cmake_import_check_files_for_OpenImageIO::oiiotool "${_IMPORT_PREFIX}/bin/oiiotool" )

# Import target "OpenImageIO::testtex" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::testtex APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::testtex PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/testtex"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::testtex )
list(APPEND _cmake_import_check_files_for_OpenImageIO::testtex "${_IMPORT_PREFIX}/bin/testtex" )

# Import target "OpenImageIO::iv" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::iv APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::iv PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/iv"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::iv )
list(APPEND _cmake_import_check_files_for_OpenImageIO::iv "${_IMPORT_PREFIX}/bin/iv" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> openimageio-3.0.8.1-r2-1.gpkg.tar: image/usr/lib64/cmake/OpenImageIO/OpenImageIOTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "OpenImageIO::OpenImageIO_Util" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::OpenImageIO_Util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::OpenImageIO_Util PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Imath::Imath"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libOpenImageIO_Util.so.3.0.8"
  IMPORTED_SONAME_RELWITHDEBINFO "libOpenImageIO_Util.so.3.0"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::OpenImageIO_Util )
list(APPEND _cmake_import_check_files_for_OpenImageIO::OpenImageIO_Util "${_IMPORT_PREFIX}/lib64/libOpenImageIO_Util.so.3.0.8" )

# Import target "OpenImageIO::OpenImageIO" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::OpenImageIO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::OpenImageIO PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Imath::Imath;OpenEXR::OpenEXR;libjpeg-turbo::jpeg;OpenEXR::OpenEXRCore;OpenColorIO::OpenColorIO"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libOpenImageIO.so.3.0.8"
  IMPORTED_SONAME_RELWITHDEBINFO "libOpenImageIO.so.3.0"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::OpenImageIO )
list(APPEND _cmake_import_check_files_for_OpenImageIO::OpenImageIO "${_IMPORT_PREFIX}/lib64/libOpenImageIO.so.3.0.8" )

# Import target "OpenImageIO::iconvert" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::iconvert APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::iconvert PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/iconvert"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::iconvert )
list(APPEND _cmake_import_check_files_for_OpenImageIO::iconvert "${_IMPORT_PREFIX}/bin/iconvert" )

# Import target "OpenImageIO::idiff" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::idiff APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::idiff PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/idiff"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::idiff )
list(APPEND _cmake_import_check_files_for_OpenImageIO::idiff "${_IMPORT_PREFIX}/bin/idiff" )

# Import target "OpenImageIO::igrep" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::igrep APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::igrep PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/igrep"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::igrep )
list(APPEND _cmake_import_check_files_for_OpenImageIO::igrep "${_IMPORT_PREFIX}/bin/igrep" )

# Import target "OpenImageIO::iinfo" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::iinfo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::iinfo PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/iinfo"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::iinfo )
list(APPEND _cmake_import_check_files_for_OpenImageIO::iinfo "${_IMPORT_PREFIX}/bin/iinfo" )

# Import target "OpenImageIO::maketx" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::maketx APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::maketx PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/maketx"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::maketx )
list(APPEND _cmake_import_check_files_for_OpenImageIO::maketx "${_IMPORT_PREFIX}/bin/maketx" )

# Import target "OpenImageIO::oiiotool" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::oiiotool APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::oiiotool PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/oiiotool"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::oiiotool )
list(APPEND _cmake_import_check_files_for_OpenImageIO::oiiotool "${_IMPORT_PREFIX}/bin/oiiotool" )

# Import target "OpenImageIO::testtex" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::testtex APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::testtex PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/testtex"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::testtex )
list(APPEND _cmake_import_check_files_for_OpenImageIO::testtex "${_IMPORT_PREFIX}/bin/testtex" )

# Import target "OpenImageIO::iv" for configuration "RelWithDebInfo"
set_property(TARGET OpenImageIO::iv APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(OpenImageIO::iv PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/iv"
  )

list(APPEND _cmake_import_check_targets OpenImageIO::iv )
list(APPEND _cmake_import_check_files_for_OpenImageIO::iv "${_IMPORT_PREFIX}/bin/iv" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
